@@ -1,2 +1,2 @@
 from binary_search import binary_search
-binary_search(A,x,lower,upper)
\ No newline at end of file
+binary_search()
\ No newline at end of file
