@@ -1,2 +1,2 @@
 from QS import QS
-QS(A,p,r)
\ No newline at end of file
+QS()
\ No newline at end of file
